package cn.com.infosec.i18n;

import java.net.URL;
import java.net.URLClassLoader;
import java.util.Locale;

public class MissingEntryException extends RuntimeException {
   protected final String resource;
   protected final String key;
   protected final ClassLoader loader;
   protected final Locale locale;
   private String debugMsg;

   public MissingEntryException(String message, String resource, String key, Locale locale, ClassLoader loader) {
      super(message);
      this.resource = resource;
      this.key = key;
      this.locale = locale;
      this.loader = loader;
   }

   public MissingEntryException(String message, Throwable cause, String resource, String key, Locale locale, ClassLoader loader) {
      super(message, cause);
      this.resource = resource;
      this.key = key;
      this.locale = locale;
      this.loader = loader;
   }

   public String getKey() {
      return this.key;
   }

   public String getResource() {
      return this.resource;
   }

   public ClassLoader getClassLoader() {
      return this.loader;
   }

   public Locale getLocale() {
      return this.locale;
   }

   public String getDebugMsg() {
      if (this.debugMsg == null) {
         this.debugMsg = "Can not find entry " + this.key + " in resource file " + this.resource + " for the locale " + this.locale + ".";
         ClassLoader var1;
         if ((var1 = this.loader) instanceof URLClassLoader) {
            URL[] var5 = ((URLClassLoader)var1).getURLs();
            String var2 = this.debugMsg;
            this.debugMsg = var2 + " The following entries in the classpath were searched: ";

            for(int var6 = 0; var6 != var5.length; ++var6) {
               String var3 = this.debugMsg;
               StringBuilder var4;
               StringBuilder var10001 = var4 = new StringBuilder;
               var4.<init>(String.valueOf(var3));
               this.debugMsg = var10001.append(var5[var6]).append(" ").toString();
            }
         }
      }

      return this.debugMsg;
   }
}
